@@ -273,6 +273,12 @@ class InlineFormView(GetMethodFieldMixin, RelatedInlineView):
     def has_changed(self):
         return self.formset.has_changed()
 
+    def get_title(self):
+        return (
+            self.model._meta.verbose_name if self.max_num and self.max_num <= 1
+            else self.model._meta.verbose_name_plural
+        )
+
 
 class TabularInlineFormView(InlineFormView):
 
