@@ -53,6 +53,27 @@ def flatten_fieldsets(fieldsets):
     return field_names
 
 
+def get_fieldsets_without_disallowed_fields(request, fieldsets, disallowed_fields):
+    generated_fieldsets = []
+
+    for title, fieldset_values in fieldsets:
+        fieldset_values = dict(fieldset_values)
+        if 'fields' in fieldset_values:
+            fieldset_values['fields'] = [
+                field for field in fieldset_values.pop('fields')
+                if field not in disallowed_fields
+            ]
+        if 'fieldsets' in fieldset_values:
+            fieldsets = get_fieldsets_without_disallowed_fields(
+                request, fieldset_values.pop('fieldsets'), disallowed_fields
+            )
+            if fieldsets:
+                fieldset_values['fieldsets'] = fieldsets
+        if set(fieldset_values.keys()) & {'fields', 'fieldsets', 'inline_view_inst'}:
+            generated_fieldsets.append((title, fieldset_values))
+    return generated_fieldsets
+
+
 def get_inline_views_from_fieldsets(fieldsets):
     """Returns a list of field names from an admin fieldsets structure."""
     inline_views = []
